import { DesignUsage } from './DesignUsage';
import { QRData } from './QRData';
import { ColorPalette } from './ColorPalette';
export declare class Design {
    constructor(usage?: DesignUsage);
    static fromBytes(bytes: Uint8Array): Design;
    static fromQRData(values: QRData | QRData[]): Design;
    /** The design's title (UTF-16 encoded, up to 42 bytes). */
    title: string | undefined;
    /** The player ID (2 bytes). */
    playerId: number;
    /** The creator's name (UTF-16 encoded, up to 18 bytes). */
    creator: string | undefined;
    /** The creator's sex (1 byte). */
    sex: number;
    /** The village ID (2 bytes). */
    villageId: number;
    /** The village name (UTF-16 encoded, up to 18 bytes). */
    village: string | undefined;
    /** The language ID (1 byte). */
    languageId: number;
    /** The country ID (1 byte). */
    countryId: number;
    /** The region ID (1 byte). */
    regionId: number;
    /** The color palette (15 bytes). */
    colorPalette: ColorPalette;
    /** The color (this field's purpose is currently unknown) (1 byte). */
    color: number;
    /** The looks (this field's purpose is currently unknown) (1 byte). */
    looks: number;
    /** The usage. */
    private _usage;
    get usage(): DesignUsage;
    set usage(value: DesignUsage);
    /** The usage ID. */
    get usageId(): number;
    set usageId(value: number);
    /** Each pixel's color data. */
    private _colorData;
    get colorData(): Uint8Array;
    set colorData(value: Uint8Array);
    private refreshColorData;
    private createColorData;
    getBytes(): Uint8Array;
    getQRData(): QRData[];
    loadBytes(bytes: Uint8Array): void;
    private loadMetadataBytes;
    loadQRData(values: QRData | QRData[]): void;
    private loadProQRData;
}
