"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
function getByteSubset(data, offset, length) {
    return data.subarray(offset, offset + length);
}
exports.getByteSubset = getByteSubset;
function getString(data, offset, length) {
    const bytes = getByteSubset(data, offset, length);
    const result = new TextDecoder('utf-16le', { ignoreBOM: true }).decode(bytes);
    return result.includes('\u0000') ? result.split('\u0000', 1)[0] : result;
}
exports.getString = getString;
function getNumber(data, offset, length) {
    return getByteSubset(data, offset, length)
        .reduce((result, b) => (result << 8) + b, 0);
}
exports.getNumber = getNumber;
function setByteSubset(data, offset, bytes) {
    data.set(bytes, offset);
}
exports.setByteSubset = setByteSubset;
function setString(data, offset, length, value) {
    // Convert the string to UTF-16 LE
    // NOTE: This may not truncate multi-code unit characters properly. Code points
    // that require more than 2 bytes may be malformed.
    const bytes = new Uint8Array(length);
    for (let i = 0; i < value.length && i * 2 < bytes.length; i++) {
        const charCode = value.charCodeAt(i);
        bytes[i * 2] = charCode;
        bytes[i * 2 + 1] = charCode >> 8;
    }
    setByteSubset(data, offset, bytes);
}
exports.setString = setString;
function setNumber(data, offset, length, value) {
    for (let i = 0; i < length; i++) {
        data[offset + i] = value >> (8 * (length - i - 1));
    }
}
exports.setNumber = setNumber;
function calculateParity(data, previousValue = 0) {
    return data.reduce((parity, byte) => parity ^ byte, previousValue);
}
exports.calculateParity = calculateParity;
